﻿using System;
using System.Collections.Generic;
using System.Windows.Forms;

namespace ScreenSaver
{
    static class Program
    {
        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main(string[] args)
        {
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);

#if DEBUG //Boot up in fullscreen when debugging
            args = new string[] { "/s"};
#endif

            if (args.Length > 0)
            {
                string firstArgument = args[0].ToLower().Trim();
                string secondArgument = null;

                //Handle cases where arguments are seperated by colon.
                //Example: /c:1234567 or /P:1234567
                if (firstArgument.Length > 2)
                {
                    secondArgument = firstArgument.Substring(3).Trim();
                    firstArgument = firstArgument.Substring(0, 2);
                }
                else if (args.Length > 1)
                {
                    secondArgument = args[1];
                }

                if (firstArgument == "/c") //Configuration mode
                {
                    Application.Run(new SettingsForm());
                }
                else if (firstArgument == "/p") //Preview Mode
                {
                    if (secondArgument == null)
                    {
                        MessageBox.Show("Sorry, but the expected windows handle was not provided.",
                            "Screensaver", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                    }

                    IntPtr previewHandle = new IntPtr(long.Parse(secondArgument));
                    Application.Run(new ScreenSaverForm(previewHandle));
                }
                else if (firstArgument == "/s") //Full screen mode
                {
                    ShowScreenSaverInFirst();
                }
                else //Undefined argument
                {
                    MessageBox.Show("Sorry, but the command line argument \"" + firstArgument +
                        "\" is not valid.", "Screensaver", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                }
            }
            else //No arguments treat like /c
            {
                Application.Run(new SettingsForm());
            }
        }

        /// <summary>
        /// Untested logic
        /// </summary>
        private static void ShowScreenSaverInAllMonitors()
        {
            foreach (Screen screen in Screen.AllScreens)
            {
                ScreenSaverForm screensaver = new ScreenSaverForm(screen.Bounds);
                Application.Run(screensaver);
            }
        }

        private static void ShowScreenSaverInFirst()
        {
            if (Screen.AllScreens.Length > 0)
            {
                ScreenSaverForm screensaver = new ScreenSaverForm(Screen.AllScreens[0].Bounds);
                Application.Run(screensaver);
            }
            else
            {
                const string MESSAGE = "The screensaver did not have a monitor to show on./n/nPress OK to exit";
                MessageBox.Show(MESSAGE, Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
            }
        }
    }
}
