﻿// Template by Brian Ferguson.
// Install to see it displayed properly in the windows enviroment.
// App will boot up in screensaver mode (/s) when in debug mode
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Runtime.InteropServices;
using ScreenSaver;
using System.Media;
using System.Drawing.Drawing2D;

namespace ScreenSaver
{
    public partial class ScreenSaverForm : Form
    {
        private Point _lastMousePos;
        private bool _preview;
        // The minimum distance that the cursor has to move before the screensaver exits
        // Decrease this to make the screensaver more sensitive to the mouse
        private const int _MOVE_DISTANCE = 5;

        public ScreenSaverForm(Rectangle bounds)
        {
            InitializeComponent();
            LoadFormState();
            this.Bounds = bounds;
        }

        /// <summary>
        /// Put anything in here that changes the form state, like loading settings
        /// </summary>
        private void LoadFormState()
        {
            Cursor.Hide();
            // Give focus to the window so it responds to key press
            // When shown after installed the window will most often not get focus
            // without this line
            NativeMethods.SetForegroundWindow(this.Handle);
        }

        /// <summary>
        /// This is the constructor for the preview mode of the form.
        /// Do adittional operations here like shrinking stuff.
        /// </summary>
        public ScreenSaverForm(IntPtr PreviewHandle)
        {
            InitializeComponent();
            LoadFormState();

            //Set the preview window as the parent of this window
            NativeMethods.SetParent(this.Handle, PreviewHandle);

            //Make this a child window so it will close when the parent dialog closes
            long windowID = NativeMethods.GetWindowLong(this.Handle, NativeMethods.WINDOW_LONG_INDEX) | NativeMethods.WINDOW_LONG_OFFSET;
            NativeMethods.SetWindowLong(this.Handle, NativeMethods.WINDOW_LONG_INDEX, new IntPtr(windowID));

            //Place our window inside the parent
            Rectangle ParentRect;
            NativeMethods.GetClientRect(PreviewHandle, out ParentRect);
            Size = ParentRect.Size;

            _preview = true;
        }

        protected override void OnKeyPress(KeyPressEventArgs e)
        {
            if (!_preview)
            {
                Application.Exit();
            }
        }

        // Register all controls to this event handler
        private void ScreenSaver_MouseMove(object sender, MouseEventArgs e)
        {
            if (!_preview)
            {
                if (!_lastMousePos.IsEmpty)
                {
                    bool hasMovedOnX = (Math.Abs(_lastMousePos.X - e.X) > _MOVE_DISTANCE);
                    bool hasMovedOnY = (Math.Abs(_lastMousePos.Y - e.Y) > _MOVE_DISTANCE);

                    //Terminate if mouse is moved a significant distance
                    if (hasMovedOnX || hasMovedOnY)
                    {
                        Application.Exit();
                    }
                }

                _lastMousePos = e.Location;
            }
        }

        // Register all controls to this event handler
        private void ScreenSaver_MouseClick(object sender, MouseEventArgs e)
        {
            if (!_preview)
            {
                Application.Exit();
            }
        }
    }
}
